import os
import torch
import numpy as np
from PIL import Image

class LH_IMAGECUT:
    """
    将图片按方向和份数分割并保存的节点
    """
    
    def __init__(self):
        self.output_dir = "output/lh_imagecut"
        # 确保输出目录存在
        os.makedirs(self.output_dir, exist_ok=True)
    
    @classmethod
    def INPUT_TYPES(cls):
        return {
            "required": {
                "image": ("IMAGE",),
                "cut_direction": (["horizontal", "vertical"],),
                "num_pieces": ("INT", {"default": 2, "min": 1, "max": 10}),
                "filename_prefix": ("STRING", {"default": "cut_"}),
            }
        }

    RETURN_TYPES = ("STRING",)
    FUNCTION = "cut_image"
    CATEGORY = "LH"

    def cut_image(self, image, cut_direction, num_pieces, filename_prefix):
        # 将tensor转换为PIL图像
        if isinstance(image, torch.Tensor):
            image = (image[0].cpu().numpy() * 255).astype(np.uint8)
            image = Image.fromarray(image)
        
        # 获取图像尺寸
        width, height = image.size
        
        # 根据方向计算每份的大小
        if cut_direction == "horizontal":
            piece_size = height // num_pieces
            for i in range(num_pieces):
                # 裁剪图片
                top = i * piece_size
                bottom = top + piece_size if i < num_pieces - 1 else height
                piece = image.crop((0, top, width, bottom))
                
                # 保存图片
                output_path = os.path.join(self.output_dir, f"{filename_prefix}{i+1}.png")
                piece.save(output_path)
        else:  # vertical
            piece_size = width // num_pieces
            for i in range(num_pieces):
                # 裁剪图片
                left = i * piece_size
                right = left + piece_size if i < num_pieces - 1 else width
                piece = image.crop((left, 0, right, height))
                
                # 保存图片
                output_path = os.path.join(self.output_dir, f"{filename_prefix}{i+1}.png")
                piece.save(output_path)
        
        return (f"图片已成功切割为{num_pieces}份并保存到 {self.output_dir} 目录",)
NODE_CLASS_MAPPINGS = {
    "LH_IMAGECUT": LH_IMAGECUT,
}